"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _Client_users, _Client_feeds, _Client_content, _Client_app, _Client_user, _Client_util;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BaseClient_1 = require("./BaseClient");
const CaptchaError_1 = require("../errors/CaptchaError");
const ContentManager_1 = require("../managers/ContentManager");
const FeedManager_1 = require("../managers/FeedManager");
const iFunnyError_1 = require("../errors/iFunnyError");
const UserManager_1 = require("../managers/UserManager");
const Util_1 = require("../utils/Util");
const form_data_1 = __importDefault(require("form-data"));
const AppManager_1 = require("../managers/AppManager");
/**
 * Client for the iFunny API.
 * @extends BaseClient
 * @template Authorized
 */
class Client extends BaseClient_1.BaseClient {
    /**
     * @param config The config for the Client
     * @param payload Payload for the client if applicable
     */
    constructor(config, payload = {}) {
        super(config, payload);
        /**
         * User manager object
         */
        _Client_users.set(this, void 0);
        /**
         * Feed manager object
         */
        _Client_feeds.set(this, void 0);
        /**
         * Content manager object
         */
        _Client_content.set(this, void 0);
        _Client_app.set(this, void 0);
        _Client_user.set(this, null);
        /**
         * Client utility class
         */
        _Client_util.set(this, void 0);
        __classPrivateFieldSet(this, _Client_util, new Util_1.Util(this), "f");
        __classPrivateFieldSet(this, _Client_users, new UserManager_1.UserManager(this, this.config.cacheConfig), "f");
        __classPrivateFieldSet(this, _Client_content, new ContentManager_1.ContentManager(this, this.config.cacheConfig), "f");
        __classPrivateFieldSet(this, _Client_feeds, new FeedManager_1.FeedManager(this), "f");
        __classPrivateFieldSet(this, _Client_app, new AppManager_1.AppManager(this), "f");
        this.instance.interceptors.request.use((config) => {
            var _a;
            config.headers ?? (config.headers = this.config.headers);
            (_a = config.headers).Authorization ?? (_a.Authorization = this.authorization);
            return config;
        });
        this.instance.interceptors.response.use((onSuccess) => onSuccess, (onFail) => {
            if (!this.util.isAxiosError(onFail) || !onFail.response)
                throw onFail;
            if (!this.util.isAPIError(onFail.response.data))
                throw onFail;
            if (iFunnyError_1.iFunnyError.isRawCaptchaError(this, onFail.response.data)) {
                throw new CaptchaError_1.CaptchaError(this, onFail.response.data);
            }
            throw new iFunnyError_1.iFunnyError(this, onFail.response.data);
        });
    }
    /**
     * Utility class for the client
     */
    get util() {
        return __classPrivateFieldGet(this, _Client_util, "f");
    }
    /**
     * Basic token used by the client.\
     * If not set in constructor, one was generated
     */
    get basic() {
        var _a;
        return ((_a = this.config).basic || (_a.basic = this.util.createBasicAuth({
            clientId: this.config.clientId,
            clientSecret: this.config.clientSecret,
            length: this.config.basicLength,
        })));
    }
    /**
     * Sets the basic token for the Client. Must be a string
     */
    set basic(value) {
        this.config.basic = value;
    }
    async primeBasic(basic) {
        await this.instance.get(ifunny_api_types_1.Endpoints.counters, {
            headers: { Authorization: `Basic ${(basic ?? (basic = this.basic))}` },
        });
        // ? Takes ~15 seconds to prime the basic token
        await this.util.sleep(1000 * 15);
        return basic;
    }
    /**
     * The bearer token for the client
     */
    get bearer() {
        return this.config.bearer;
    }
    /**
     * Sets the bearer token for the client. If set to null, the client will not use a bearer token.
     */
    set bearer(value) {
        this.config.bearer = value || null;
        this.instance.defaults.headers.common.Authorization = this.isAuthorized()
            ? `Bearer ${this.bearer}`
            : `Basic ${this.basic}`;
    }
    /**
     * The authorization string used for requests
     */
    get authorization() {
        return this.bearer ? `Bearer ${this.bearer}` : `Basic ${this.basic}`;
    }
    /**
     * Is the client using a bearer token to make requests?
     */
    isAuthorized() {
        return !!this.bearer;
    }
    /**
     * Updates the Client's payload
     * @returns The Client instance
     */
    async fetch() {
        if (!this.isAuthorized()) {
            throw new Error("Client is not authorized with a bearer token. Please generate one with Client#login");
        }
        const response = await this.instance.get(ifunny_api_types_1.Endpoints.account);
        const data = response.data;
        this.payload = data.data;
        return this;
    }
    /**
     * The client's user manager
     */
    get users() {
        return __classPrivateFieldGet(this, _Client_users, "f");
    }
    /**
     * The content feeds for the Client
     */
    get feeds() {
        return __classPrivateFieldGet(this, _Client_feeds, "f");
    }
    /**
     * The Client's Content manager
     */
    get content() {
        return __classPrivateFieldGet(this, _Client_content, "f");
    }
    get app() {
        return __classPrivateFieldGet(this, _Client_app, "f");
    }
    async user() {
        if (!this.isAuthorized()) {
            return null;
        }
        await this.fetch();
        return (__classPrivateFieldSet(this, _Client_user, __classPrivateFieldGet(this, _Client_user, "f") ?? await this.users.fetch(this.id), "f"));
    }
    async login(email, password) {
        if (this.isAuthorized()) {
            return await this.fetch();
        }
        if (!email || !password) {
            throw new TypeError("email and password are required if a bearer hasn't been set");
        }
        const auth = `Basic ${this.basic}`;
        const data = new form_data_1.default();
        data.append("grant_type", "password");
        data.append("username", email);
        data.append("password", password);
        const response = await this.instance.post(ifunny_api_types_1.Endpoints.token, data, {
            headers: Object.assign({
                accept: "application/json",
                applicationstate: 1,
                authorization: auth,
                connection: "Keep-Alive",
                "content-type": "application/x-www-form-urlencoded",
            }, data.getHeaders()),
        });
        this.bearer = response.data.access_token;
        return await this.fetch();
    }
    /**
     * Signs up for an iFunny account.
     * @param options.nick The nick of the account to sign up with. Checks if the nick is taken.
     * @param options.email The email to sign up with. Checks if the email is taken.
     * @param options.password The password to sign up with
     * @param options.acceptMailOffers Should the Client sign up for the mailing list. Never set this to true.
     * @param options.login Should the client login after sign up? (Default: true)
     * @returns The instance of the client
     */
    async signUp(options) {
        const data = new form_data_1.default();
        data.append("reg_type", "pwd");
        data.append("nick", options.nick);
        data.append("email", options.email);
        data.append("password", options.password);
        data.append("accept_mailing", !!options.acceptMailing ? "1" : "0");
        const response = await this.instance.post(ifunny_api_types_1.Endpoints.user(), data, { headers: data.getHeaders() });
        this.payload.id = response.data.data.id;
        if (options.login ?? true) {
            return await this.login(options.email, options.password);
        }
        return this;
    }
    get(key) {
        return (this.payload?.[key] ?? null);
    }
    get about() {
        return this.get("about");
    }
    get id() {
        return this.get("id");
    }
}
exports.Client = Client;
_Client_users = new WeakMap(), _Client_feeds = new WeakMap(), _Client_content = new WeakMap(), _Client_app = new WeakMap(), _Client_user = new WeakMap(), _Client_util = new WeakMap();
exports.default = Client;
//# sourceMappingURL=Client.js.map