"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CaptchaError = void 0;
const iFunnyError_1 = require("./iFunnyError");
/**
 * Represents a captcha returned by the API
 * * If this is thrown, you need to catch it, open the url in any browser, solve it, then attempt to make the EXACT same request
 * @extends iFunnyError<RESTAPIErrorCaptchaRequired>
 */
class CaptchaError extends iFunnyError_1.iFunnyError {
    /**
     * @param client Client instance
     * @param error Raw Error returned by the API
     */
    constructor(client, error) {
        super(client, error);
    }
    /**
     * The type of the captcha
     */
    get type() {
        return this.raw.data.type;
    }
    /**
     * URL to open to solve the captcha.
     */
    get captchaUrl() {
        return this.raw.data.captcha_url;
    }
}
exports.CaptchaError = CaptchaError;
exports.default = CaptchaError;
//# sourceMappingURL=CaptchaError.js.map