"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _iFunnyError_error, _iFunnyError_client;
Object.defineProperty(exports, "__esModule", { value: true });
exports.iFunnyError = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const CaptchaError_1 = require("./CaptchaError");
/**
 * A class representing an error thrown by iFunny.ts.
 * @extends Error
 * @template APIError - The type of the error response returned by the iFunny REST API.
 */
class iFunnyError extends Error {
    /**
     * @param client Client instance attached to the Error
     * @param error The error thrown by the API
     */
    constructor(client, error) {
        super(error.error_description);
        _iFunnyError_error.set(this, void 0);
        _iFunnyError_client.set(this, void 0);
        __classPrivateFieldSet(this, _iFunnyError_client, client, "f");
        if (iFunnyError.isRawCaptchaError(client, error)) {
            this.message += ": " + error.data.captcha_url;
        }
        __classPrivateFieldSet(this, _iFunnyError_error, error, "f");
        Error.captureStackTrace?.(this, iFunnyError);
    }
    /**
     * Client instance that threw the error
     */
    get client() {
        return __classPrivateFieldGet(this, _iFunnyError_client, "f");
    }
    /**
     * The error code for the error
     */
    get code() {
        return this.raw.error;
    }
    /**
     * Status code returned by the API
     */
    get status() {
        return this.raw.status;
    }
    /**
     * Raw error returned by the API
     */
    get raw() {
        return __classPrivateFieldGet(this, _iFunnyError_error, "f");
    }
    /**
     * The name of the error
     */
    get name() {
        return `${this.constructor.name} - ${this.code} [${this.status}]`;
    }
    /**
     * Type guards an object into an iFunnyError
     * @param error Object to type guard
     * @returns error is iFunnyError
     */
    static isiFunnyError(error) {
        return error instanceof iFunnyError;
    }
    /**
     * Type guards an object into captcha like error
     * @param client Client instance to use util class for
     * @param error Error response from AxiosError#response#data
     * @internal
     */
    static isRawCaptchaError(client, error) {
        if (!client.util.isAPIError(error))
            return false;
        if (error.error !== ifunny_api_types_1.IFUNNY_ERRORS.CAPTCHA_REQUIRED)
            return false;
        if (!client.util.hasProperty(error, "data"))
            return false;
        if (!client.util.hasProperty(error.data, "captcha_url"))
            return false;
        if (!client.util.hasProperty(error.data, "type"))
            return false;
        if (typeof error.data.type !== "string")
            return false;
        if (typeof error.data.captcha_url !== "string")
            return false;
        return true;
    }
    /**
     * Type guards an object into CaptchaError
     * @param error Error to validate
     * @returns error is CaptchaError
     */
    static isCaptchaError(error) {
        return error instanceof CaptchaError_1.CaptchaError;
    }
    isCaptchaError(error) {
        return iFunnyError.isCaptchaError(error ?? this);
    }
}
exports.iFunnyError = iFunnyError;
_iFunnyError_error = new WeakMap(), _iFunnyError_client = new WeakMap();
//# sourceMappingURL=iFunnyError.js.map