"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseUser = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BanSmall_1 = require("./BanSmall");
const Base_1 = require("./Base");
const MemeExperience_1 = require("./MemeExperience");
/**
 * Base User class that user class will inherit from.
 * @extends Base<APIUserProfile>
 */
class BaseUser extends Base_1.Base {
    /**
     * @param client The client instance
     * @param payload Payload to create the User with
     */
    constructor(client, payload) {
        super(client, payload);
        this.payload = payload;
        this.endpointUrl = ifunny_api_types_1.Endpoints.user(payload.id);
    }
    /**
     * The user's about text
     * @alias bio
     */
    get about() {
        return this.get("about");
    }
    /**
     * Does the user have you blocked?
     */
    get areYouBlocked() {
        return this.get("are_you_blocked");
    }
    /**
     * Collection of Bans the user has
     */
    get bans() {
        const bans = this.get("bans") ?? [];
        return bans.map((ban) => new BanSmall_1.BanSmall(this, ban));
    }
    /**
     * The user's about text
     * @alias about
     */
    get bio() {
        return this.about;
    }
    /**
     * The block type if the user is blocked
     */
    get blockType() {
        return this.get("block_type");
    }
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias is_available_for_chat
     */
    get canChat() {
        return this.isAvailableForChat;
    }
    /**
     * The user's chat privacy
     */
    get chatPrivacy() {
        return this.get("messaging_privacy_status");
    }
    /**
     * Cover image background color
     */
    get coverColor() {
        return this.get("cover_bg_color");
    }
    /**
     * Cover imamge url
     */
    get coverUrl() {
        return this.get("cover_url");
    }
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias can_chat
     */
    get isAvailableForChat() {
        return this.get("is_available_for_chat");
    }
    /**
     * Is the user banned?
     */
    get isBanned() {
        return this.get("is_banned");
    }
    /**
     * Is the user blocked by the Client?
     */
    get isBlocked() {
        return this.get("is_blocked");
    }
    /**
     * Is the user deleted?
     */
    get isDeleted() {
        return this.get("is_deleted");
    }
    /**
     * Is the user's account private?
     */
    get isPrivate() {
        return this.get("is_private");
    }
    /**
     * Is the user subscribed to updates?
     */
    get isSubscribedToUpdates() {
        return this.get("is_subscribed_to_updates");
    }
    /**
     * Is the user subscribed to the Client?
     */
    get isSubscriber() {
        return this.get("is_in_subscribers");
    }
    /**
     * Is the client subscribed to the user?
     */
    get isSubscription() {
        return this.get("is_in_subscriptions");
    }
    /**
     * Is the user verified?
     */
    get isVerified() {
        return this.get("is_verified");
    }
    /**
     * The user's unique uri
     * @alias web_url
     */
    get link() {
        return this.get("web_url");
    }
    /**
     * The user's meme experience
     */
    get memeExperience() {
        return new MemeExperience_1.MemeExperience(this.get("meme_experience"));
    }
    /**
     * TODO: Add description for messengerActive
     */
    get messengerActive() {
        return this.get("messenger_active");
    }
    /**
     * TODO: Add description for messenger_token
     */
    get messengerToken() {
        return this.get("messenger_token");
    }
    /**
     * Nickname of the user
     * @alias username
     */
    get nick() {
        return this.get("nick");
    }
    /**
     * The nick color of the user if they have one, else null
     */
    get nickColor() {
        return this.get("nick_color");
    }
    /**
     * The users `num` object
     * @alias `stats`
     */
    get num() {
        return this.get("num");
    }
    /**
     * Profile photo of the user
     */
    get profilePhoto() {
        return this.get("photo");
    }
    /**
     * All the user's linked social media accounts
     */
    get socials() {
        return this.get("social");
    }
    /**
     * The users  `num` object
     * @alias num
     */
    get stats() {
        return this.num;
    }
    /**
     * The users subscription count
     */
    get totalSubscriptions() {
        return this.num.subscriptions;
    }
    /**
     * The users subsciber count
     */
    get totalSubscribers() {
        this.payload;
        return this.num.subscribers;
    }
    /**
     * How many posts the user has on their profile
     */
    get totalPosts() {
        return this.num.total_posts;
    }
    /**
     * How many original posts the user has
     */
    get totalOriginalPosts() {
        return this.num.created;
    }
    /**
     * How many posts the has that are republishes (***NOT original***)
     */
    get totalRepublishedPosts() {
        return this.totalPosts - this.totalOriginalPosts;
    }
    /**
     * How many features the user has
     */
    get totalFeatures() {
        return this.num.featured;
    }
    /**
     * How many smiles the user has on their profile
     */
    get totalSmiles() {
        return this.num.total_smiles;
    }
    /**
     * How many achievements the user has
     */
    get totalAchievements() {
        return this.num.achievements;
    }
    /**
     * Nickname of the user
     * @alias nick
     */
    get username() {
        return this.nick;
    }
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString() {
        return this.nick;
    }
}
exports.BaseUser = BaseUser;
exports.default = BaseUser;
//# sourceMappingURL=BaseUser.js.map