"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _News_payload, _News_client;
Object.defineProperty(exports, "__esModule", { value: true });
exports.News = void 0;
const Content_1 = __importDefault(require("./Content"));
/**
 * Represents a News object from the Activity Feed
 */
class News {
    /**
     * @param client The Client associated with the News
     * @param news Payload of the News Object
     */
    constructor(client, news) {
        _News_payload.set(this, void 0);
        _News_client.set(this, void 0);
        __classPrivateFieldSet(this, _News_payload, news, "f");
        __classPrivateFieldSet(this, _News_client, client, "f");
    }
    /**
     * The Client associated with the News
     */
    get client() {
        return __classPrivateFieldGet(this, _News_client, "f");
    }
    /**
     * Payload of the News
     */
    get payload() {
        return __classPrivateFieldGet(this, _News_payload, "f");
    }
    /**
     * Get the value of a property of the News object from the payload
     * @param key Key of the property
     * @returns The value of the property
     */
    get(key) {
        return (this.payload[key] ?? null);
    }
    /**
     * The Date of the News object
     */
    get date() {
        return new Date(this.get("date") * 1000);
    }
    /**
     * The type of the News object
     */
    get type() {
        return this.get("type");
    }
    /**
     * The ID of the Ban associated with the News object
     */
    get banId() {
        return this.get("banId");
    }
    /**
     * The message associated with the Ban associated with the News object
     */
    get banMessage() {
        return this.get("banTypeMessage");
    }
    /**
     * The type of the Ban associated with the News object
     */
    get banType() {
        return this.get("banType");
    }
    /**
     * The raw comment associated with the News object
     */
    get comment() {
        return this.get("comment");
    }
    /**
     * The content associated with the News object
     */
    get content() {
        return this.get("content");
    }
    /**
     * The current number of active strikes for the Client
     */
    get countActiveStrike() {
        return this.get("countActiveStrike");
    }
    /**
     * The date that the Ban or Strike will expire
     */
    get dateUntil() {
        const date = this.get("date_until");
        return date ? new Date(date * 1000) : null;
    }
    /**
     * The date that the Ban or Strike expired
     */
    get expiredAt() {
        const date = this.get("expiredAt");
        return date ? new Date(date * 1000) : null;
    }
    /**
     * The URL of the image associated with the News object
     */
    get imageUrl() {
        return this.get("imageUrl");
    }
    /**
     * The Content mentioned in this news object
     */
    get mentionContent() {
        const content = this.get("mention_content");
        return content ? new Content_1.default(this.client, content) : null;
    }
    /**
     * The users mentioned in this news object
     */
    get mentionUsers() {
        return this.get("mention_users");
    }
    /**
     * The type of purchase associated with the News object
     */
    get purchaseType() {
        return this.get("purchaseType");
    }
    /**
     * The raw reply associated with the News object
     */
    get reply() {
        return this.get("reply");
    }
    /**
     * The number of smiles associated with the News object
     */
    get smiles() {
        return this.get("smiles");
    }
    /**
     * The ID of the strike associated with the News object
     */
    get strikeId() {
        return this.get("strikeId");
    }
    /**
     * The message associated with the strike associated with the News object
     */
    get text() {
        return this.get("text");
    }
    /**
     * The title of the News object
     */
    get title() {
        return this.get("title");
    }
    /**
     * The URL of the News object
     */
    get url() {
        return this.get("url");
    }
    /**
     * The User associated with the News object
     */
    get user() {
        return this.get("user");
    }
    /**
     * The username associated with the News object
     */
    get username() {
        return this.get("username");
    }
}
exports.News = News;
_News_payload = new WeakMap(), _News_client = new WeakMap();
exports.default = News;
//# sourceMappingURL=News.js.map