import { APIClientUser as ClientPayload } from "@ifunny/ifunny-api-types";
import { EventEmitter } from "eventemitter3";
import { ICachingOptions } from "node-ts-cache";
import { AxiosRequestHeaders } from "axios";
export interface ClientConfig {
    basic: string | null;
    basicLength: 156 | 112;
    bearer: string | null;
    headers: AxiosRequestHeaders;
    clientId: string;
    clientSecret: string;
    cacheConfig: ICachingOptions;
}
export type ClientOptions = Partial<ClientConfig>;
/**
 * Base Client for the Client to extend
 * @extends EventEmitter
 */
export declare class BaseClient extends EventEmitter {
    #private;
    /**
     * @param config Options to initialize the BaseClient with
     * @param payload The payload for the client if applicable
     */
    protected constructor(config?: ClientOptions, payload?: Partial<ClientPayload>);
    /**
     * Default Config for the Client
     */
    static readonly DEFAULT_CONFIG: ClientConfig;
    /**
     * Current config for the Client
     */
    get config(): ClientConfig;
    /**
     * Gets the payload
     */
    get payload(): Partial<ClientPayload>;
    /**
     * Prevents overwriting the payload
     */
    set payload(value: Partial<ClientPayload>);
    /**
     * Calls eval with the client set as the "this" context.
     * @param script The script to evaluate
     * @returns The result of the script
     */
    protected _eval(script: string): any;
    /**
     * Converts the Client's payload into JSON like data
     * @returns JSON string representation of the Client
     */
    toJSON(): string;
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${client}!`); //  Logs: "Hello from iFunnyChef" or "Hello from Guest Client"
     */
    toString(): string;
}
export default BaseClient;
//# sourceMappingURL=BaseClient.d.ts.map