import { RESTAPIErrorResponse, RESTAPIiFunnyError } from "@ifunny/ifunny-api-types";
import { CaptchaError } from "./CaptchaError";
import { Client } from "../client/Client";
/**
 * A class representing an error thrown by iFunny.ts.
 * @extends Error
 * @template APIError - The type of the error response returned by the iFunny REST API.
 */
export declare class iFunnyError<APIError extends RESTAPIErrorResponse = RESTAPIErrorResponse> extends Error {
    #private;
    /**
     * @param client Client instance attached to the Error
     * @param error The error thrown by the API
     */
    constructor(client: Client, error: APIError);
    /**
     * Client instance that threw the error
     */
    get client(): Client;
    /**
     * The error code for the error
     */
    get code(): RESTAPIiFunnyError;
    /**
     * Status code returned by the API
     */
    get status(): 403 | 400 | 401 | 404;
    /**
     * Raw error returned by the API
     */
    get raw(): APIError;
    /**
     * The name of the error
     */
    get name(): string;
    /**
     * Type guards an object into an iFunnyError
     * @param error Object to type guard
     * @returns error is iFunnyError
     */
    static isiFunnyError(error: unknown): error is iFunnyError;
    /**
     * Type guards an object into CaptchaError
     * @param error Error to validate
     * @returns error is CaptchaError
     */
    static isCaptchaError(error: unknown): error is CaptchaError;
    /**
     * Type Guards this Error into CaptchaError
     */
    isCaptchaError(): this is CaptchaError;
    /**
     * Type Guards error into CaptchaError
     * @param error Error to Type Guard
     */
    isCaptchaError(error: unknown): error is CaptchaError;
}
//# sourceMappingURL=iFunnyError.d.ts.map