import { CachedManager } from "./CachedManager";
import { Client } from "../client/Client";
import { ICachingOptions } from "node-ts-cache";
import { User } from "../structures/User";
/**
 * Manages iFunny Users
 * @extends CachedManager<User>
 */
export declare class UserManager extends CachedManager<typeof User> {
    /**
     * @param client Client instance attached to the UserManager
     */
    constructor(client: Client, cacheConfig: ICachingOptions);
    /**
     * Checks if a nick is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your nick
     * @param nick Nick to check availability of
     */
    isNickAvailable(nick: string): Promise<boolean>;
    /**
     * Checks if an email is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your email
     * @param email Email to check availability of
     */
    isEmailAvailable(email: string): Promise<boolean>;
    /**
     * Fetches a user by their ID or Nick
     * @param idOrNick Id or nick of the user
     * @param byNick Whether to lookup by nick (Default: false)
     * @param cached Whater to return the cached result (Default: true)
     * @returns User|null if the client is authorized
     * @throws iFunnyError
     */
    fetch(idOrNick: string, byNick?: boolean, cached?: boolean): Promise<User | null>;
}
export default UserManager;
//# sourceMappingURL=UserManager.d.ts.map