import { type APIContent, type APIContentCopyright, type APIContentData, type APIContentNums, type APIContentShotStatus, type APIContentSource, type APIContentState, type APIContentThumbnail, type APIContentType, type APIContentVisibility, type APIFeedFrom, type Size } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Creator } from "./Creator";
import type { Client } from "../client/Client";
/**
 * The Base Content that all Content Types will extend
 * @extends Base<APIContent>
 */
export declare class BaseContent extends Base<APIContent> {
    #private;
    /**
     * @param client Client instance associated with the Content
     * @param payload Payload of the Content
     */
    constructor(client: Client, payload: APIContent);
    /**
     * This data is typically retrieved by using the content's type as a key for the content.
     * @example
     * content.payload[content.type] // Key isn't always the type
     */
    get data(): APIContentData | null;
    /**
     * The creator of the post
     * @alias creator
     */
    get author(): Creator | null;
    /**
     * Content background color
     */
    get bgColor(): string | null;
    /**
     * Can the post be boosted?
     */
    get canBeBoosted(): boolean;
    /**
     * Content url that can be opened in app
     */
    get canonicalUrl(): string;
    /**
     * Copywright information attached to the content
     */
    get copyright(): APIContentCopyright;
    /**
     * The creator of the post
     * @alias author
     */
    get creator(): Creator | null;
    /**
     * When the content was created
     */
    get createdAt(): Date;
    /**
     * Not sure what this is
     */
    get fastStart(): boolean;
    /**
     * Title set by iFunny
     */
    get fixedTitle(): string | null;
    /**
     * The ID of the Content.
     */
    get id(): string;
    /**
     * Was the post removed by iFunny?
     */
    get isAbused(): boolean;
    /**
     * Was the post featured?
     */
    get isFeatured(): boolean;
    /**
     * Is the Content pinned by the author?
     */
    get isPinned(): boolean;
    /**
     * Is the Content republished by the Client?
     */
    get isRepublished(): boolean;
    /**
     * Is the Content smiled by the Client?
     */
    get isSmiled(): boolean;
    /**
     * When the Content was featured if it was featured
     */
    get featuredAt(): Date | null;
    /**
     * The tag to use for the 'from' parameter
     */
    get ftag(): APIFeedFrom | null;
    /**
     * The link of the content that can be opened in iFunny
     */
    get link(): string;
    /**
     * The numbers attached to the Content
     * @alias stats
     */
    get num(): APIContentNums;
    /**
     * Text generated from iFunny's OCR (Optical Character Recognition)
     */
    get ocrText(): string | null;
    /**
     * Does the Content use the Old Watermark
     */
    get oldWatermark(): boolean;
    /**
     * When the Content was published or will publish
     */
    get publishedAt(): Date;
    /**
     * The risk level of the Content\
     * Default: `1`
     */
    get risk(): number;
    /**
     * The shot status of the content\
     * `approved` - Content can be posted in comments\
     * `shot` - Content can't be posted in comments\
     * `hardShot` - Content was removed by iFunny and is not viewable
     */
    get shotStatus(): APIContentShotStatus;
    /**
     * The size of the Content
     */
    get size(): Size;
    /**
     * The source of the content if it exists
     */
    get source(): APIContentSource | null;
    /**
     * The state of the Content
     */
    get state(): APIContentState;
    /**
     * The numbers attached to the Content
     * @alias num
     */
    get stats(): APIContentNums;
    /**
     * All tags on the Content
     */
    get tags(): string[];
    /**
     * Thumbnail of the Content
     */
    get thumbnail(): APIContentThumbnail;
    /**
     * The Title of the content
     */
    get title(): string;
    /**
     * URL of the original source if it exists
     */
    get tracebackUrl(): string | null;
    /**
     * The type of the post
     */
    get type(): APIContentType;
    /**
     * URL of the Content
     */
    get url(): string;
    /**
     * The Content's visibility status\
     * `public` - Content shows up in collective and explore
     * `subscribers` - Content is hidden from Collective and Explore
     * `closed` - Content is not visible by anyone but the author
     */
    get visibility(): APIContentVisibility;
    /**
     * When concatenated with a string, this automatically returns the content's id instead of the Content object.
     * @example
     * console.log(`Found post: ${content}`); //  Logs: Found post: 2hu2ab8J
     */
    toString(): string;
}
export default BaseContent;
//# sourceMappingURL=BaseContent.d.ts.map