import { Base } from "./Base";
import type { Client } from "../client/Client";
import type { User } from "./User";
import type { APIContentCreator, APINickColor, APIProfilePhoto, APIUserNums, APIUserRating } from "@ifunny/ifunny-api-types";
/**
 * Preresents a Content Creator on iFunny
 * @extends Base<APIContentCreator>
 */
export declare class Creator extends Base<APIContentCreator> {
    #private;
    /**
     * @param client Client instance for the Creator
     * @param payload Payload of the content creator
     */
    constructor(client: Client, payload: APIContentCreator);
    /**
     * The Content Creator's User Object
     * @returns Promise that resolves to the User Object
     */
    user(): Promise<User>;
    /**
     * Is the creator banned?
     * @returns boolean
     */
    get isBanned(): boolean;
    /**
     * Is the creator blocked by the Client?
     * @returns boolean
     */
    get isBlocked(): boolean;
    /**
     * Is the creator a deleted user?
     * @returns boolean
     */
    get isDeleted(): boolean;
    /**
     * Is the creator subscribed to the Client?
     * @returns boolean
     */
    get isSubscriber(): boolean;
    /**
     * Is the Client subscribed to the Creator?
     * @returns boolean
     */
    get isSubscription(): boolean;
    /**
     * Is the Creator verified?
     * @returns boolean
     */
    get isVerified(): boolean;
    /**
     * The creator's nick
     * @alias username
     */
    get nick(): string;
    /**
     * The creator's nick color
     * @returns A hex color code without the # prefix
     * @example
     * nick_color: "55FF00"
     */
    get nickColor(): APINickColor | null;
    /**
     * The creator's nums
     * @alias stats
     */
    get num(): APIUserNums;
    /**
     * The creator's original nick\
     * ? iFunny sometimes censors users nicknames
     * @example
     * nick: "garespectingyoass"
     * original_nick: "garapingyoass"
     */
    get originalNick(): string;
    /**
     * The creator's profile photo
     */
    get photo(): APIProfilePhoto | null;
    /**
     * The creator's rating
     */
    get rating(): APIUserRating;
    /**
     * The creator's stats
     * @alias num
     */
    get stats(): APIUserNums;
    /**
     * Total number of posts the creator has\
     * ? This isn't in Creator.num for some reason
     */
    get totalPosts(): number;
    /**
     * The creator's username
     * @alias nick
     */
    get username(): string;
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString(): string;
}
export default Creator;
//# sourceMappingURL=Creator.d.ts.map