import { type APICommentAuthor, type APIProfilePhoto, type APISimpleUser, type APIUserNums } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import type { Client } from "../client/Client";
import type { User } from "./User";
/**
 * Simple user class, typically found in pagination
 * @extends Base<APISimpleUser>
 */
export declare class SimpleUser extends Base<APISimpleUser> {
    #private;
    /**
     * @param client Client attached to the SimpleUser
     * @param payload Payload for the SimpleUser
     */
    constructor(client: Client, payload: APISimpleUser | APICommentAuthor);
    /**
     * Fetches the User object
     * @returns The User object with more information
     */
    user(): Promise<User | null>;
    /**
     * Is the user banned?
     */
    get isBanned(): boolean;
    /**
     * Is the user blocked by the Client?
     */
    get isBlocked(): boolean;
    /**
     * Is the user deleted?
     */
    get isDeleted(): boolean;
    /**
     * Is the user subcribed to the Client?
     */
    get isSubscriber(): boolean;
    /**
     * Is the Cilent subscribed to the user?
     */
    get isSubscription(): boolean;
    /**
     * Is the user verified?
     */
    get isVerified(): boolean;
    /**
     * User's nick
     * @alias username
     */
    get nick(): string;
    /**
     * Nums for the user
     * @alias stats
     */
    get num(): APIUserNums;
    /**
     * Original nick for the user
     */
    get originalNick(): string;
    /**
     * Profile photo for the user
     */
    get photo(): APIProfilePhoto | null;
    /**
     * Stats for the user
     * @alias num
     */
    get stats(): APIUserNums;
    /**
     * Amount of posts the user has
     */
    get totalPosts(): number;
    /**
     * Amount of subscribers the user has
     */
    get totalSubscribers(): number;
    /**
     * Amount of subcriptions the user has
     */
    get totalSubscriptions(): number;
    /**
     * User's nick
     * @alias nick
     */
    get username(): string;
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString(): string;
}
export default SimpleUser;
//# sourceMappingURL=SimpleUser.d.ts.map